@@ -5,7 +5,6 @@ import json
 from datetime import datetime, timezone
 from typing import Dict, Any
 import requests
-from urllib.parse import urlencode
 import hashlib
 import base64
 
@@ -78,7 +77,8 @@ class AuthService:
 
         headers = {
             "signature": self.get_signature(req_json),
-            "Content-Type": "application/json"
+            "Content-Type": "application/json",
+            "Authorization": "Null"
         }
 
         url = (self.config.get("ida.ekyc.url") if is_ekyc
@@ -152,24 +152,23 @@ class AuthService:
         return s
 
     def get_certificate(self, application_id: str, reference_id: str) -> Dict[str, Any]:
-        """Get certificate from server"""
+        """Get certificate from server (public endpoint, no query params, no auth)"""
         url = self.config.get("ida.certificate.url")
-        params = {
-            "applicationId": application_id,
-            "referenceId": reference_id
-        }
-        full_url = f"{url}?{urlencode(params)}"
+        logger.debug(f"[Cert] Fetching certificate from: {url}")
 
         try:
-            session = self._create_session()
-            response = session.get(full_url, verify=self.config.get("ida.ssl.verify", False))
+            # Fetch certificate directly as string (no query params, no auth headers - public endpoint)
+            response = requests.get(url, verify=self.config.get("ida.ssl.verify", False))
             response.raise_for_status()
-            data = response.json()
+            certificate_string = response.text
             
-            if not data or "response" not in data:
-                raise RuntimeError("Invalid certificate response")
+            logger.debug(f"[Cert] Certificate received length={len(certificate_string) if certificate_string else 0} chars")
             
-            return data["response"]
+            if not certificate_string or not certificate_string.strip():
+                logger.error("[Cert] Empty certificate response")
+                raise RuntimeError("Empty certificate response")
+            
+            return {"certificate": certificate_string}
         except Exception as e:
             logger.error(f"[Cert] Failed to get certificate: {e}")
             raise
@@ -184,14 +183,8 @@ class AuthService:
             req_json, False, True, False, None, key_dir, partner_id)
 
     def _create_session(self) -> requests.Session:
-        """Create requests session with auth token"""
+        """Create requests session (no auth token needed)"""
         session = requests.Session()
-        auth_token = self._generate_auth_token()
-        if auth_token:
-            session.headers.update({
-                "Cookie": f"Authorization={auth_token}",
-                "Authorization": f"Bearer {auth_token}"
-            })
         
         if not self.config.get("ida.ssl.verify", False):
             session.verify = False
@@ -200,74 +193,6 @@ class AuthService:
         
         return session
 
-    def _generate_auth_token(self) -> str:
-        """Generate authentication token"""
-        try:
-            request_body = {
-                "clientId": self.config.get("clientId", ""),
-                "secretKey": self.config.get("secretKey", ""),
-                "appId": self.config.get("appId", "")
-            }
-
-            dt = datetime.now(timezone.utc)
-            request_time = dt.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'
-            request = {
-                "requesttime": request_time,
-                "request": request_body
-            }
-
-            headers = {"Content-Type": "application/json"}
-            url = self.config.get("ida.authmanager.url")
-            response = requests.post(
-                url,
-                json=request,
-                headers=headers,
-                verify=self.config.get("ida.ssl.verify", False)
-            )
-
-            auth_header = response.headers.get("authorization") or response.headers.get("Authorization")
-            if auth_header:
-                token = auth_header.replace("Bearer ", "").strip()
-                if token:
-                    return token
-            
-            set_cookie_header = response.headers.get("Set-Cookie", "") or response.headers.get("set-cookie", "")
-            if isinstance(set_cookie_header, list):
-                set_cookie_values = set_cookie_header
-            elif set_cookie_header:
-                set_cookie_values = [set_cookie_header]
-            else:
-                set_cookie_values = []
-            
-            if set_cookie_values:
-                for cookie in set_cookie_values:
-                    auth_pos = cookie.find("Authorization=")
-                    if auth_pos >= 0:
-                        token_start = auth_pos + len("Authorization=")
-                        token_end = cookie.find(";", token_start)
-                        if token_end == -1:
-                            token_end = len(cookie)
-                        token = cookie[token_start:token_end].strip()
-                        if token:
-                            return token
-
-            try:
-                if response.content:
-                    body_json = response.json()
-                    if isinstance(body_json, dict):
-                        if "token" in body_json:
-                            return body_json["token"]
-                        if "response" in body_json and isinstance(body_json["response"], dict):
-                            if "token" in body_json["response"]:
-                                return body_json["response"]["token"]
-            except:
-                pass
-
-            logger.warning("[Auth] No Authorization token found")
-        except Exception as e:
-            logger.error("[Auth] Failed to generate auth token", exc_info=True)
-        return ""
-
     def _get_utc_current_datetime_iso_string(self) -> str:
         """Get current UTC datetime as ISO string with Z suffix"""
         dt = datetime.now(timezone.utc)
