@@ -7,7 +7,6 @@ import hashlib
 from datetime import datetime, timezone
 from typing import Dict, Any
 import requests
-from urllib.parse import urlencode
 
 from ..dto.request.auth_request_dto import AuthRequestDTO
 from ..dto.request.request_dto import RequestDTO
@@ -77,7 +76,8 @@ class EkycService:
         req_json = json.dumps(request_map)
         headers = {
             "signature": self.auth_service.get_signature(req_json),
-            "Content-Type": "application/json"
+            "Content-Type": "application/json",
+            "Authorization": "Null"
         }
 
         url = self.config.get("ida.ekyc.url")
@@ -239,28 +239,22 @@ class EkycService:
         return hashlib.sha256(cert_der).digest()
 
     def _get_certificate_for_encryption(self, data: str, is_internal: bool):
-        """Get certificate for encryption"""
-        session = self._create_session()
+        """Get certificate for encryption (public endpoint, no query params, no auth)"""
         url = self.config.get("ida.certificate.url")
-        reference_id = self.config.get("ida.reference.id", "")
-        if not reference_id:
-            raise ValueError("ida.reference.id is required for certificate retrieval")
-        params = {
-            "applicationId": "IDA",
-            "referenceId": reference_id
-        }
-        full_url = f"{url}?{urlencode(params)}"
+        logger.debug(f"[Cert] Fetching certificate from: {url}")
 
-        response = session.get(full_url, verify=self.config.get("ida.ssl.verify", False))
+        # Fetch certificate directly as string (no query params, no auth headers - public endpoint)
+        response = requests.get(url, verify=self.config.get("ida.ssl.verify", False))
         response.raise_for_status()
-        resp = response.json()
+        certificate_string = response.text
         
-        if not resp or "response" not in resp:
-            raise RuntimeError("Invalid certificate response")
-
-        certificate_str = resp["response"]["certificate"]
-        cert_trimmed = self._trim_begin_end(certificate_str)
+        logger.debug(f"[Cert] Certificate received length={len(certificate_string) if certificate_string else 0} chars")
+        
+        if not certificate_string or not certificate_string.strip():
+            logger.error("[Cert] Empty certificate response")
+            raise RuntimeError("Empty certificate response")
 
+        cert_trimmed = self._trim_begin_end(certificate_string)
         cert_bytes = base64.b64decode(cert_trimmed)
         return x509.load_der_x509_certificate(cert_bytes, default_backend())
 
@@ -274,16 +268,9 @@ class EkycService:
         return p_key
 
     def _create_session(self) -> requests.Session:
-        """Create requests session with auth token"""
+        """Create requests session (no auth token needed)"""
         session = requests.Session()
         
-        auth_token = self._generate_auth_token()
-        if auth_token:
-            session.headers.update({
-                "Cookie": f"Authorization={auth_token}",
-                "Authorization": f"Bearer {auth_token}"
-            })
-        
         if not self.config.get("ida.ssl.verify", False):
             session.verify = False
             import urllib3
@@ -291,73 +278,6 @@ class EkycService:
         
         return session
 
-    def _generate_auth_token(self) -> str:
-        """Generate authentication token"""
-        try:
-            body = {
-                "clientId": self.config.get("clientId", ""),
-                "secretKey": self.config.get("secretKey", ""),
-                "appId": self.config.get("appId", "")
-            }
-
-            dt = datetime.now(timezone.utc)
-            request_time = dt.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'
-            request = {
-                "requesttime": request_time,
-                "request": body
-            }
-
-            headers = {"Content-Type": "application/json"}
-            
-            url = self.config.get("ida.authmanager.url")
-            response = requests.post(
-                url,
-                json=request,
-                headers=headers,
-                verify=self.config.get("ida.ssl.verify", False)
-            )
-
-            auth_header = response.headers.get("authorization") or response.headers.get("Authorization")
-            if auth_header:
-                token = auth_header.replace("Bearer ", "").strip()
-                if token:
-                    return token
-            
-            set_cookie_header = response.headers.get("Set-Cookie", "") or response.headers.get("set-cookie", "")
-            if isinstance(set_cookie_header, list):
-                set_cookie_values = set_cookie_header
-            elif set_cookie_header:
-                set_cookie_values = [set_cookie_header]
-            else:
-                set_cookie_values = []
-            
-            if set_cookie_values:
-                for cookie in set_cookie_values:
-                    auth_pos = cookie.find("Authorization=")
-                    if auth_pos >= 0:
-                        token_start = auth_pos + len("Authorization=")
-                        token_end = cookie.find(";", token_start)
-                        if token_end == -1:
-                            token_end = len(cookie)
-                        token = cookie[token_start:token_end].strip()
-                        if token:
-                            return token
-
-            try:
-                if response.content:
-                    body_json = response.json()
-                    if isinstance(body_json, dict):
-                        if "token" in body_json:
-                            return body_json["token"]
-                        if "response" in body_json and isinstance(body_json["response"], dict):
-                            if "token" in body_json["response"]:
-                                return body_json["response"]["token"]
-            except:
-                pass
-        except Exception as e:
-            logger.error("[Auth] Failed to generate token", exc_info=True)
-        return ""
-
     def _get_utc_current_datetime_iso_string(self) -> str:
         """Get current UTC datetime as ISO string with Z suffix"""
         dt = datetime.now(timezone.utc)
